==> syncfusion_flutter_charts-18.3.51.tar.gz: lib/src/chart/chart_segment/spline_range_area_segment.dart <==
part of charts;

/// Creates the segments for spline area series.
///
/// Generates the spline area series points and has the [calculateSegmentPoints] method overrided to customize
/// the spline area segment point calculation.
///
/// Gets the path and color from the [series].
class SplineRangeAreaSegment extends ChartSegment {
  /// Path _borderPath;
  Path _path, _strokePath;

  ///For storing the path in RangeAreaBorderMode.excludeSides mode
  Rect _pathRect;

  /// Gets the color of the series.
  @override
  Paint getFillPaint() {
    fillPaint = Paint();
    if (_series.gradient == null) {
      if (_color != null) {
        fillPaint.color = _color;
        fillPaint.style = PaintingStyle.fill;
      }
    } else {
      fillPaint = (_pathRect != null)
          ? _getLinearGradientPaint(_series.gradient, _pathRect,
              _seriesRenderer._chartState._requireInvertedAxis)
          : fillPaint;
    }
    assert(_series.opacity >= 0,
        'The opacity value of the spline range area series should be greater than or equal to 0.');
    assert(_series.opacity <= 1,
        'The opacity value of the spline range area series should be less than or equal to 1.');
    if (fillPaint.color != null) {
      fillPaint.color =
          (_series.opacity < 1 && fillPaint.color != Colors.transparent)
              ? fillPaint.color.withOpacity(_series.opacity)
              : fillPaint.color;
    }
    _defaultFillColor = fillPaint;
    return fillPaint;
  }

  /// Gets the border color of the series.
  @override
  Paint getStrokePaint() {
    final Paint strokePaint = Paint();
    strokePaint
      ..style = PaintingStyle.stroke
      ..strokeWidth = _series.borderWidth;
    if (_series.borderGradient != null) {
      strokePaint.shader =
          _series.borderGradient.createShader(_strokePath.getBounds());
    } else if (_strokeColor != null) {
      strokePaint.color = _series.borderColor;
    }
    _series.borderWidth == 0
        ? strokePaint.color = Colors.transparent
        : strokePaint.color;
    strokePaint.strokeCap = StrokeCap.round;
    _defaultStrokeColor = strokePaint;
    return strokePaint;
  }

  /// Calculates the rendering bounds of a segment.
  @override
  void calculateSegmentPoints() {}

  /// Draws segment in series bounds.
  @override
  void onPaint(Canvas canvas) {
    final SplineRangeAreaSeries<dynamic, dynamic> splineRangeAreaSeries =
        _seriesRenderer._series;
    _pathRect = _path.getBounds();
    canvas.drawPath(
        _path, (_series.gradient == null) ? fillPaint : getFillPaint());
    if (strokePaint.color != Colors.transparent) {
      _drawDashedLine(
          canvas,
          _series.dashArray,
          strokePaint,
          splineRangeAreaSeries.borderDrawMode == RangeAreaBorderMode.all
              ? _path
              : _strokePath);
    }
  }
}

==> syncfusion_flutter_charts-18.4.48.tar.gz: lib/src/chart/chart_segment/spline_range_area_segment.dart <==
part of charts;

/// Creates the segments for spline area series.
///
/// Generates the spline area series points and has the [calculateSegmentPoints] method overrided to customize
/// the spline area segment point calculation.
///
/// Gets the path and color from the `series`.
class SplineRangeAreaSegment extends ChartSegment {
  /// Path _borderPath;
  Path _path, _strokePath;

  ///For storing the path in RangeAreaBorderMode.excludeSides mode
  Rect _pathRect;

  /// Gets the color of the series.
  @override
  Paint getFillPaint() {
    fillPaint = Paint();
    if (_series.gradient == null) {
      if (_color != null) {
        fillPaint.color = _color;
        fillPaint.style = PaintingStyle.fill;
      }
    } else {
      fillPaint = (_pathRect != null)
          ? _getLinearGradientPaint(_series.gradient, _pathRect,
              _seriesRenderer._chartState._requireInvertedAxis)
          : fillPaint;
    }
    assert(_series.opacity >= 0,
        'The opacity value of the spline range area series should be greater than or equal to 0.');
    assert(_series.opacity <= 1,
        'The opacity value of the spline range area series should be less than or equal to 1.');
    if (fillPaint.color != null) {
      fillPaint.color =
          (_series.opacity < 1 && fillPaint.color != Colors.transparent)
              ? fillPaint.color.withOpacity(_series.opacity)
              : fillPaint.color;
    }
    _defaultFillColor = fillPaint;
    return fillPaint;
  }

  /// Gets the border color of the series.
  @override
  Paint getStrokePaint() {
    final Paint strokePaint = Paint();
    strokePaint
      ..style = PaintingStyle.stroke
      ..strokeWidth = _series.borderWidth;
    if (_series.borderGradient != null) {
      strokePaint.shader =
          _series.borderGradient.createShader(_strokePath.getBounds());
    } else if (_strokeColor != null) {
      strokePaint.color = _series.borderColor;
    }
    _series.borderWidth == 0
        ? strokePaint.color = Colors.transparent
        : strokePaint.color;
    strokePaint.strokeCap = StrokeCap.round;
    _defaultStrokeColor = strokePaint;
    return strokePaint;
  }

  /// Calculates the rendering bounds of a segment.
  @override
  void calculateSegmentPoints() {}

  /// Draws segment in series bounds.
  @override
  void onPaint(Canvas canvas) {
    final SplineRangeAreaSeries<dynamic, dynamic> splineRangeAreaSeries =
        _seriesRenderer._series;
    _pathRect = _path.getBounds();
    canvas.drawPath(
        _path, (_series.gradient == null) ? fillPaint : getFillPaint());
    if (strokePaint.color != Colors.transparent) {
      _drawDashedLine(
          canvas,
          _series.dashArray,
          strokePaint,
          splineRangeAreaSeries.borderDrawMode == RangeAreaBorderMode.all
              ? _path
              : _strokePath);
    }
  }
}
